@@ -1,5 +1,5 @@
 /*
- * $Id: config.h,v 1.27 2008/01/07 15:47:08 hno Exp $
+ * $Id$
  *
  * AUTHOR: Duane Wessels
  *
@@ -35,8 +35,13 @@
 #define SQUID_CONFIG_H
 
 #include "autoconf.h"		/* For GNU autoconf variables */
+
+#if !defined(HAVE_SQUID)
+/* sub-packages define their own version details */
 #include "version.h"
 
+#endif
+
 /* To keep API definitions clear */
 #ifdef __cplusplus
 #define SQUIDCEXTERN extern "C"
@@ -435,15 +440,16 @@ typedef union {
  */
 #if WITH_VALGRIND
 #include <valgrind/memcheck.h>
-#undef VALGRIND_MAKE_NOACCESS
-#undef VALGRIND_MAKE_WRITABLE
-#undef VALGRIND_MAKE_READABLE
 /* A little glue for older valgrind version prior to 3.2.0 */
 #ifndef VALGRIND_MAKE_MEM_NOACCESS
 #define VALGRIND_MAKE_MEM_NOACCESS VALGRIND_MAKE_NOACCESS
 #define VALGRIND_MAKE_MEM_UNDEFINED VALGRIND_MAKE_WRITABLE
 #define VALGRIND_MAKE_MEM_DEFINED VALGRIND_MAKE_READABLE
 #define VALGRIND_CHECK_MEM_IS_ADDRESSABLE VALGRIND_CHECK_WRITABLE
+#else
+#undef VALGRIND_MAKE_NOACCESS
+#undef VALGRIND_MAKE_WRITABLE
+#undef VALGRIND_MAKE_READABLE
 #endif
 #else
 #define VALGRIND_MAKE_MEM_NOACCESS(a,b) (0)
