@@ -4,9 +4,10 @@
 /* forward decls */
 
 class ErrorState;
+class HttpRequest;
 
 #include "comm.h"
-#include "IPAddress.h"
+#include "ip/IpAddress.h"
 
 class FwdServer
 {
@@ -43,7 +44,7 @@ public:
     bool checkRetry();
     bool checkRetriable();
     void dispatch();
-    void pconnPush(int fd, const char *host, int port, const char *domain, IPAddress &client_addr);
+    void pconnPush(int fd, const peer *_peer, const HttpRequest *req, const char *domain, IpAddress &client_addr);
 
     bool dontRetry() { return flags.dont_retry; }
 
@@ -99,7 +100,7 @@ private:
         unsigned int forward_completed:1;
     } flags;
 
-    IPAddress src; /* Client address for this connection. Needed for transparent operations. */
+    IpAddress src; /* Client address for this connection. Needed for transparent operations. */
 };
 
 #endif
